@@ -45,7 +45,7 @@ class FreqDict(models.Model):
             if int(lemmas[key]['CategoryNum']) > 12:
                 continue
             cat = SyntacticCategory.objects.get(pk=int(lemmas[key]['CategoryNum']))
-            ls.append(Lemma.objects.create(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
+            ls.append(Lemma(pk=int(key),FreqDict=self,Label=lemmas[key]['Word'],Category=cat,Frequency=int(lemmas[key]['Freq'])))
         Lemma.objects.bulk_create(ls)
         for key in wfs:
             wf = WordForm.objects.create(pk=int(key),Frequency = int(wfs[key]['Freq']))
